" Vim syntax file
" Language: C glib extension (for version 2.28.0)
" Maintainer: David Nečas (Yeti) <yeti@physics.muni.cz>
" Last Change: 2011-03-14
" URL: http://physics.muni.cz/~yeti/vim/gtk-syntax.tar.gz
" Generated By: vim-syn-gen.py
" Options:
"    Deprecated declarations are not highlighted by default.
"    let glib_enable_deprecated = 1
"       highlights deprecated declarations too (like normal declarations)
"    let glib_deprecated_errors = 1
"       highlights deprecated declarations as Errors

syn keyword glibFunction alloca atexit g_access g_array_append_vals g_array_free g_array_get_element_size g_array_insert_vals g_array_new g_array_prepend_vals g_array_ref g_array_remove_index g_array_remove_index_fast g_array_remove_range g_array_set_size g_array_sized_new g_array_sort g_array_sort_with_data g_array_unref g_ascii_digit_value g_ascii_dtostr g_ascii_formatd g_ascii_strcasecmp g_ascii_strdown g_ascii_strncasecmp g_ascii_strtod g_ascii_strtoll g_ascii_strtoull g_ascii_strup g_ascii_tolower g_ascii_toupper g_ascii_xdigit_value g_assertion_message g_assertion_message_cmpnum g_assertion_message_cmpstr g_assertion_message_error g_assertion_message_expr g_async_queue_length g_async_queue_length_unlocked g_async_queue_lock g_async_queue_new g_async_queue_new_full g_async_queue_pop g_async_queue_pop_unlocked g_async_queue_push g_async_queue_push_sorted g_async_queue_push_sorted_unlocked g_async_queue_push_unlocked g_async_queue_ref g_async_queue_sort g_async_queue_sort_unlocked g_async_queue_timed_pop g_async_queue_timed_pop_unlocked g_async_queue_try_pop g_async_queue_try_pop_unlocked g_async_queue_unlock g_async_queue_unref g_atexit g_atomic_int_add g_atomic_int_compare_and_exchange g_atomic_int_exchange_and_add g_atomic_int_get g_atomic_int_set g_atomic_pointer_compare_and_exchange g_atomic_pointer_get g_atomic_pointer_set g_base64_decode g_base64_decode_inplace g_base64_decode_step g_base64_encode g_base64_encode_close g_base64_encode_step g_bit_lock g_bit_nth_lsf g_bit_nth_msf g_bit_storage g_bit_trylock g_bit_unlock g_bookmark_file_add_application g_bookmark_file_add_group g_bookmark_file_error_quark g_bookmark_file_free g_bookmark_file_get_added g_bookmark_file_get_app_info g_bookmark_file_get_applications g_bookmark_file_get_description g_bookmark_file_get_groups g_bookmark_file_get_icon g_bookmark_file_get_is_private g_bookmark_file_get_mime_type g_bookmark_file_get_modified g_bookmark_file_get_size g_bookmark_file_get_title g_bookmark_file_get_uris g_bookmark_file_get_visited g_bookmark_file_has_application g_bookmark_file_has_group g_bookmark_file_has_item g_bookmark_file_load_from_data g_bookmark_file_load_from_data_dirs g_bookmark_file_load_from_file g_bookmark_file_move_item g_bookmark_file_new g_bookmark_file_remove_application g_bookmark_file_remove_group g_bookmark_file_remove_item g_bookmark_file_set_added g_bookmark_file_set_app_info g_bookmark_file_set_description g_bookmark_file_set_groups g_bookmark_file_set_icon g_bookmark_file_set_is_private g_bookmark_file_set_mime_type g_bookmark_file_set_modified g_bookmark_file_set_title g_bookmark_file_set_visited g_bookmark_file_to_data g_bookmark_file_to_file g_build_filename g_build_filenamev g_build_path g_build_pathv g_byte_array_append g_byte_array_free g_byte_array_new g_byte_array_prepend g_byte_array_ref g_byte_array_remove_index g_byte_array_remove_index_fast g_byte_array_remove_range g_byte_array_set_size g_byte_array_sized_new g_byte_array_sort g_byte_array_sort_with_data g_byte_array_unref g_cache_destroy g_cache_insert g_cache_key_foreach g_cache_new g_cache_remove g_chdir g_checksum_copy g_checksum_free g_checksum_get_digest g_checksum_get_string g_checksum_new g_checksum_reset g_checksum_type_get_length g_checksum_update g_child_watch_add g_child_watch_add_full g_child_watch_source_new g_chmod g_clear_error g_compute_checksum_for_data g_compute_checksum_for_string g_convert g_convert_error_quark g_convert_with_fallback g_convert_with_iconv g_creat g_datalist_clear g_datalist_foreach g_datalist_get_flags g_datalist_id_get_data g_datalist_id_remove_no_notify g_datalist_id_set_data_full g_datalist_init g_datalist_set_flags g_datalist_unset_flags g_dataset_destroy g_dataset_foreach g_dataset_id_get_data g_dataset_id_remove_no_notify g_dataset_id_set_data_full g_date_add_days g_date_add_months g_date_add_years g_date_clamp g_date_clear g_date_compare g_date_days_between g_date_free g_date_get_day g_date_get_day_of_year g_date_get_days_in_month g_date_get_iso8601_week_of_year g_date_get_julian g_date_get_monday_week_of_year g_date_get_monday_weeks_in_year g_date_get_month g_date_get_sunday_week_of_year g_date_get_sunday_weeks_in_year g_date_get_weekday g_date_get_year g_date_is_first_of_month g_date_is_last_of_month g_date_is_leap_year g_date_new g_date_new_dmy g_date_new_julian g_date_order g_date_set_day g_date_set_dmy g_date_set_julian g_date_set_month g_date_set_parse g_date_set_time_t g_date_set_time_val g_date_set_year g_date_strftime g_date_subtract_days g_date_subtract_months g_date_subtract_years g_date_time_add g_date_time_add_days g_date_time_add_full g_date_time_add_hours g_date_time_add_minutes g_date_time_add_months g_date_time_add_seconds g_date_time_add_weeks g_date_time_add_years g_date_time_compare g_date_time_difference g_date_time_equal g_date_time_format g_date_time_get_day_of_month g_date_time_get_day_of_week g_date_time_get_day_of_year g_date_time_get_hour g_date_time_get_microsecond g_date_time_get_minute g_date_time_get_month g_date_time_get_second g_date_time_get_seconds g_date_time_get_timezone_abbreviation g_date_time_get_utc_offset g_date_time_get_week_numbering_year g_date_time_get_week_of_year g_date_time_get_year g_date_time_get_ymd g_date_time_hash g_date_time_is_daylight_savings g_date_time_new g_date_time_new_from_timeval_local g_date_time_new_from_timeval_utc g_date_time_new_from_unix_local g_date_time_new_from_unix_utc g_date_time_new_local g_date_time_new_now g_date_time_new_now_local g_date_time_new_now_utc g_date_time_new_utc g_date_time_ref g_date_time_to_local g_date_time_to_timeval g_date_time_to_timezone g_date_time_to_unix g_date_time_to_utc g_date_time_unref g_date_to_struct_tm g_date_valid g_date_valid_day g_date_valid_dmy g_date_valid_julian g_date_valid_month g_date_valid_weekday g_date_valid_year g_dcgettext g_dgettext g_dir_close g_dir_open g_dir_read_name g_dir_rewind g_direct_equal g_direct_hash g_dngettext g_double_equal g_double_hash g_dpgettext g_dpgettext2 g_error_copy g_error_free g_error_matches g_error_new g_error_new_literal g_error_new_valist g_file_error_from_errno g_file_error_quark g_file_get_contents g_file_open_tmp g_file_read_link g_file_set_contents g_file_test g_filename_display_basename g_filename_display_name g_filename_from_uri g_filename_from_utf8 g_filename_to_uri g_filename_to_utf8 g_find_program_in_path g_fopen g_format_size_for_display g_fprintf g_free g_freopen g_get_application_name g_get_charset g_get_current_dir g_get_current_time g_get_environ g_get_filename_charsets g_get_home_dir g_get_host_name g_get_language_names g_get_locale_variants g_get_monotonic_time g_get_prgname g_get_real_name g_get_real_time g_get_system_config_dirs g_get_system_data_dirs g_get_tmp_dir g_get_user_cache_dir g_get_user_config_dir g_get_user_data_dir g_get_user_name g_get_user_runtime_dir g_get_user_special_dir g_getenv g_hash_table_destroy g_hash_table_find g_hash_table_foreach g_hash_table_foreach_remove g_hash_table_foreach_steal g_hash_table_get_keys g_hash_table_get_values g_hash_table_insert g_hash_table_iter_get_hash_table g_hash_table_iter_init g_hash_table_iter_next g_hash_table_iter_remove g_hash_table_iter_steal g_hash_table_lookup g_hash_table_lookup_extended g_hash_table_new g_hash_table_new_full g_hash_table_ref g_hash_table_remove g_hash_table_remove_all g_hash_table_replace g_hash_table_size g_hash_table_steal g_hash_table_steal_all g_hash_table_unref g_hook_alloc g_hook_compare_ids g_hook_destroy g_hook_destroy_link g_hook_find g_hook_find_data g_hook_find_func g_hook_find_func_data g_hook_first_valid g_hook_free g_hook_get g_hook_insert_before g_hook_insert_sorted g_hook_list_clear g_hook_list_init g_hook_list_invoke g_hook_list_invoke_check g_hook_list_marshal g_hook_list_marshal_check g_hook_next_valid g_hook_prepend g_hook_ref g_hook_unref g_hostname_is_ascii_encoded g_hostname_is_ip_address g_hostname_is_non_ascii g_hostname_to_ascii g_hostname_to_unicode g_iconv g_iconv_close g_iconv_open g_idle_add g_idle_add_full g_idle_remove_by_data g_idle_source_new g_int64_equal g_int64_hash g_int_equal g_int_hash g_intern_static_string g_intern_string g_io_add_watch g_io_add_watch_full g_io_channel_error_from_errno g_io_channel_error_quark g_io_channel_flush g_io_channel_get_buffer_condition g_io_channel_get_buffer_size g_io_channel_get_buffered g_io_channel_get_close_on_unref g_io_channel_get_encoding g_io_channel_get_flags g_io_channel_get_line_term g_io_channel_init g_io_channel_new_file g_io_channel_read_chars g_io_channel_read_line g_io_channel_read_line_string g_io_channel_read_to_end g_io_channel_read_unichar g_io_channel_ref g_io_channel_seek_position g_io_channel_set_buffer_size g_io_channel_set_buffered g_io_channel_set_close_on_unref g_io_channel_set_encoding g_io_channel_set_flags g_io_channel_set_line_term g_io_channel_shutdown g_io_channel_unix_get_fd g_io_channel_unix_new g_io_channel_unref g_io_channel_win32_get_fd g_io_channel_win32_make_pollfd g_io_channel_win32_new_fd g_io_channel_win32_new_messages g_io_channel_win32_new_socket g_io_channel_win32_poll g_io_channel_write_chars g_io_channel_write_unichar g_io_create_watch g_key_file_error_quark g_key_file_free g_key_file_get_boolean g_key_file_get_boolean_list g_key_file_get_comment g_key_file_get_double g_key_file_get_double_list g_key_file_get_groups g_key_file_get_int64 g_key_file_get_integer g_key_file_get_integer_list g_key_file_get_keys g_key_file_get_locale_string g_key_file_get_locale_string_list g_key_file_get_start_group g_key_file_get_string g_key_file_get_string_list g_key_file_get_uint64 g_key_file_get_value g_key_file_has_group g_key_file_has_key g_key_file_load_from_data g_key_file_load_from_data_dirs g_key_file_load_from_dirs g_key_file_load_from_file g_key_file_new g_key_file_remove_comment g_key_file_remove_group g_key_file_remove_key g_key_file_set_boolean g_key_file_set_boolean_list g_key_file_set_comment g_key_file_set_double g_key_file_set_double_list g_key_file_set_int64 g_key_file_set_integer g_key_file_set_integer_list g_key_file_set_list_separator g_key_file_set_locale_string g_key_file_set_locale_string_list g_key_file_set_string g_key_file_set_string_list g_key_file_set_uint64 g_key_file_set_value g_key_file_to_data g_list_alloc g_list_append g_list_concat g_list_copy g_list_delete_link g_list_find g_list_find_custom g_list_first g_list_foreach g_list_free g_list_free_1 g_list_free_full g_list_index g_list_insert g_list_insert_before g_list_insert_sorted g_list_insert_sorted_with_data g_list_last g_list_length g_list_nth g_list_nth_data g_list_nth_prev g_list_position g_list_prepend g_list_remove g_list_remove_all g_list_remove_link g_list_reverse g_list_sort g_list_sort_with_data g_listenv g_locale_from_utf8 g_locale_to_utf8 g_log g_log_default_handler g_log_remove_handler g_log_set_always_fatal g_log_set_default_handler g_log_set_fatal_mask g_log_set_handler g_logv g_lstat g_main_context_acquire g_main_context_add_poll g_main_context_check g_main_context_default g_main_context_dispatch g_main_context_find_source_by_funcs_user_data g_main_context_find_source_by_id g_main_context_find_source_by_user_data g_main_context_get_poll_func g_main_context_get_thread_default g_main_context_invoke g_main_context_invoke_full g_main_context_is_owner g_main_context_iteration g_main_context_new g_main_context_pending g_main_context_pop_thread_default g_main_context_prepare g_main_context_push_thread_default g_main_context_query g_main_context_ref g_main_context_release g_main_context_remove_poll g_main_context_set_poll_func g_main_context_unref g_main_context_wait g_main_context_wakeup g_main_current_source g_main_depth g_main_loop_get_context g_main_loop_is_running g_main_loop_new g_main_loop_quit g_main_loop_ref g_main_loop_run g_main_loop_unref g_malloc g_malloc0 g_malloc0_n g_malloc_n g_mapped_file_get_contents g_mapped_file_get_length g_mapped_file_new g_mapped_file_ref g_mapped_file_unref g_markup_collect_attributes g_markup_error_quark g_markup_escape_text g_markup_parse_context_end_parse g_markup_parse_context_free g_markup_parse_context_get_element g_markup_parse_context_get_element_stack g_markup_parse_context_get_position g_markup_parse_context_get_user_data g_markup_parse_context_new g_markup_parse_context_parse g_markup_parse_context_pop g_markup_parse_context_push g_markup_printf_escaped g_markup_vprintf_escaped g_match_info_expand_references g_match_info_fetch g_match_info_fetch_all g_match_info_fetch_named g_match_info_fetch_named_pos g_match_info_fetch_pos g_match_info_free g_match_info_get_match_count g_match_info_get_regex g_match_info_get_string g_match_info_is_partial_match g_match_info_matches g_match_info_next g_mem_is_system_malloc g_mem_profile g_mem_set_vtable g_memdup g_mkdir g_mkdir_with_parents g_mkstemp g_mkstemp_full g_module_build_path g_module_close g_module_error g_module_make_resident g_module_name g_module_open g_module_supported g_module_symbol g_node_child_index g_node_child_position g_node_children_foreach g_node_copy g_node_copy_deep g_node_depth g_node_destroy g_node_find g_node_find_child g_node_first_sibling g_node_get_root g_node_insert g_node_insert_after g_node_insert_before g_node_is_ancestor g_node_last_child g_node_last_sibling g_node_max_height g_node_n_children g_node_n_nodes g_node_new g_node_nth_child g_node_prepend g_node_reverse_children g_node_traverse g_node_unlink g_nullify_pointer g_on_error_query g_on_error_stack_trace g_once_impl g_once_init_enter g_once_init_enter_impl g_once_init_leave g_open g_option_context_add_group g_option_context_add_main_entries g_option_context_free g_option_context_get_description g_option_context_get_help g_option_context_get_help_enabled g_option_context_get_ignore_unknown_options g_option_context_get_main_group g_option_context_get_summary g_option_context_new g_option_context_parse g_option_context_set_description g_option_context_set_help_enabled g_option_context_set_ignore_unknown_options g_option_context_set_main_group g_option_context_set_summary g_option_context_set_translate_func g_option_context_set_translation_domain g_option_error_quark g_option_group_add_entries g_option_group_free g_option_group_new g_option_group_set_error_hook g_option_group_set_parse_hooks g_option_group_set_translate_func g_option_group_set_translation_domain g_parse_debug_string g_path_get_basename g_path_get_dirname g_path_is_absolute g_path_skip_root g_pattern_match g_pattern_match_simple g_pattern_match_string g_pattern_spec_equal g_pattern_spec_free g_pattern_spec_new g_poll g_prefix_error g_print g_printerr g_printf g_printf_string_upper_bound g_propagate_error g_propagate_prefixed_error g_ptr_array_add g_ptr_array_foreach g_ptr_array_free g_ptr_array_new g_ptr_array_new_with_free_func g_ptr_array_ref g_ptr_array_remove g_ptr_array_remove_fast g_ptr_array_remove_index g_ptr_array_remove_index_fast g_ptr_array_remove_range g_ptr_array_set_free_func g_ptr_array_set_size g_ptr_array_sized_new g_ptr_array_sort g_ptr_array_sort_with_data g_ptr_array_unref g_qsort_with_data g_quark_from_static_string g_quark_from_string g_quark_to_string g_quark_try_string g_queue_clear g_queue_copy g_queue_delete_link g_queue_find g_queue_find_custom g_queue_foreach g_queue_free g_queue_get_length g_queue_index g_queue_init g_queue_insert_after g_queue_insert_before g_queue_insert_sorted g_queue_is_empty g_queue_link_index g_queue_new g_queue_peek_head g_queue_peek_head_link g_queue_peek_nth g_queue_peek_nth_link g_queue_peek_tail g_queue_peek_tail_link g_queue_pop_head g_queue_pop_head_link g_queue_pop_nth g_queue_pop_nth_link g_queue_pop_tail g_queue_pop_tail_link g_queue_push_head g_queue_push_head_link g_queue_push_nth g_queue_push_nth_link g_queue_push_tail g_queue_push_tail_link g_queue_remove g_queue_remove_all g_queue_reverse g_queue_sort g_queue_unlink g_rand_copy g_rand_double g_rand_double_range g_rand_free g_rand_int g_rand_int_range g_rand_new g_rand_new_with_seed g_rand_new_with_seed_array g_rand_set_seed g_rand_set_seed_array g_random_double g_random_double_range g_random_int g_random_int_range g_random_set_seed g_realloc g_realloc_n g_regex_check_replacement g_regex_error_quark g_regex_escape_string g_regex_get_capture_count g_regex_get_compile_flags g_regex_get_match_flags g_regex_get_max_backref g_regex_get_pattern g_regex_get_string_number g_regex_match g_regex_match_all g_regex_match_all_full g_regex_match_full g_regex_match_simple g_regex_new g_regex_ref g_regex_replace g_regex_replace_eval g_regex_replace_literal g_regex_split g_regex_split_full g_regex_split_simple g_regex_unref g_reload_user_special_dirs_cache g_remove g_rename g_return_if_fail_warning g_rmdir g_scanner_cur_line g_scanner_cur_position g_scanner_cur_token g_scanner_cur_value g_scanner_destroy g_scanner_eof g_scanner_error g_scanner_get_next_token g_scanner_input_file g_scanner_input_text g_scanner_lookup_symbol g_scanner_new g_scanner_peek_next_token g_scanner_scope_add_symbol g_scanner_scope_foreach_symbol g_scanner_scope_lookup_symbol g_scanner_scope_remove_symbol g_scanner_set_scope g_scanner_sync_file_offset g_scanner_unexp_token g_scanner_warn g_sequence_append g_sequence_foreach g_sequence_foreach_range g_sequence_free g_sequence_get g_sequence_get_begin_iter g_sequence_get_end_iter g_sequence_get_iter_at_pos g_sequence_get_length g_sequence_insert_before g_sequence_insert_sorted g_sequence_insert_sorted_iter g_sequence_iter_compare g_sequence_iter_get_position g_sequence_iter_get_sequence g_sequence_iter_is_begin g_sequence_iter_is_end g_sequence_iter_move g_sequence_iter_next g_sequence_iter_prev g_sequence_lookup g_sequence_lookup_iter g_sequence_move g_sequence_move_range g_sequence_new g_sequence_prepend g_sequence_range_get_midpoint g_sequence_remove g_sequence_remove_range g_sequence_search g_sequence_search_iter g_sequence_set g_sequence_sort g_sequence_sort_changed g_sequence_sort_changed_iter g_sequence_sort_iter g_sequence_swap g_set_application_name g_set_error g_set_error_literal g_set_prgname g_set_print_handler g_set_printerr_handler g_setenv g_shell_error_quark g_shell_parse_argv g_shell_quote g_shell_unquote g_slice_alloc g_slice_alloc0 g_slice_copy g_slice_free1 g_slice_free_chain_with_offset g_slice_get_config g_slice_get_config_state g_slice_set_config g_slist_alloc g_slist_append g_slist_concat g_slist_copy g_slist_delete_link g_slist_find g_slist_find_custom g_slist_foreach g_slist_free g_slist_free_1 g_slist_free_full g_slist_index g_slist_insert g_slist_insert_before g_slist_insert_sorted g_slist_insert_sorted_with_data g_slist_last g_slist_length g_slist_nth g_slist_nth_data g_slist_position g_slist_prepend g_slist_remove g_slist_remove_all g_slist_remove_link g_slist_reverse g_slist_sort g_slist_sort_with_data g_snprintf g_source_add_child_source g_source_add_poll g_source_attach g_source_destroy g_source_get_can_recurse g_source_get_context g_source_get_id g_source_get_name g_source_get_priority g_source_get_time g_source_is_destroyed g_source_new g_source_ref g_source_remove g_source_remove_by_funcs_user_data g_source_remove_by_user_data g_source_remove_child_source g_source_remove_poll g_source_set_callback g_source_set_callback_indirect g_source_set_can_recurse g_source_set_funcs g_source_set_name g_source_set_name_by_id g_source_set_priority g_source_unref g_spaced_primes_closest g_spawn_async g_spawn_async_with_pipes g_spawn_close_pid g_spawn_command_line_async g_spawn_command_line_sync g_spawn_error_quark g_spawn_sync g_sprintf g_stat g_static_mutex_free g_static_mutex_get_mutex_impl g_static_mutex_init g_static_private_free g_static_private_get g_static_private_init g_static_private_set g_static_rec_mutex_free g_static_rec_mutex_init g_static_rec_mutex_lock g_static_rec_mutex_lock_full g_static_rec_mutex_trylock g_static_rec_mutex_unlock g_static_rec_mutex_unlock_full g_static_rw_lock_free g_static_rw_lock_init g_static_rw_lock_reader_lock g_static_rw_lock_reader_trylock g_static_rw_lock_reader_unlock g_static_rw_lock_writer_lock g_static_rw_lock_writer_trylock g_static_rw_lock_writer_unlock g_stpcpy g_str_equal g_str_has_prefix g_str_has_suffix g_str_hash g_strcanon g_strchomp g_strchug g_strcmp0 g_strcompress g_strconcat g_strdelimit g_strdup g_strdup_printf g_strdup_vprintf g_strdupv g_strerror g_strescape g_strfreev g_string_append g_string_append_c g_string_append_len g_string_append_printf g_string_append_unichar g_string_append_uri_escaped g_string_append_vprintf g_string_ascii_down g_string_ascii_up g_string_assign g_string_chunk_clear g_string_chunk_free g_string_chunk_insert g_string_chunk_insert_const g_string_chunk_insert_len g_string_chunk_new g_string_equal g_string_erase g_string_free g_string_hash g_string_insert g_string_insert_c g_string_insert_len g_string_insert_unichar g_string_new g_string_new_len g_string_overwrite g_string_overwrite_len g_string_prepend g_string_prepend_c g_string_prepend_len g_string_prepend_unichar g_string_printf g_string_set_size g_string_sized_new g_string_truncate g_string_vprintf g_strip_context g_strjoin g_strjoinv g_strlcat g_strlcpy g_strndup g_strnfill g_strreverse g_strrstr g_strrstr_len g_strsignal g_strsplit g_strsplit_set g_strstr_len g_strtod g_strv_length g_test_add_data_func g_test_add_func g_test_add_vtable g_test_bug g_test_bug_base g_test_create_case g_test_create_suite g_test_get_root g_test_init g_test_log_buffer_free g_test_log_buffer_new g_test_log_buffer_pop g_test_log_buffer_push g_test_log_msg_free g_test_log_set_fatal_handler g_test_log_type_name g_test_maximized_result g_test_message g_test_minimized_result g_test_queue_destroy g_test_queue_free g_test_rand_double g_test_rand_double_range g_test_rand_int g_test_rand_int_range g_test_run g_test_run_suite g_test_suite_add g_test_suite_add_suite g_test_timer_elapsed g_test_timer_last g_test_timer_start g_test_trap_assertions g_test_trap_fork g_test_trap_has_passed g_test_trap_reached_timeout g_thread_create_full g_thread_error_quark g_thread_exit g_thread_foreach g_thread_get_initialized g_thread_init g_thread_init_glib g_thread_init_with_errorcheck_mutexes g_thread_join g_thread_pool_free g_thread_pool_get_max_idle_time g_thread_pool_get_max_threads g_thread_pool_get_max_unused_threads g_thread_pool_get_num_threads g_thread_pool_get_num_unused_threads g_thread_pool_new g_thread_pool_push g_thread_pool_set_max_idle_time g_thread_pool_set_max_threads g_thread_pool_set_max_unused_threads g_thread_pool_set_sort_function g_thread_pool_stop_unused_threads g_thread_pool_unprocessed g_thread_self g_thread_set_priority g_time_val_add g_time_val_from_iso8601 g_time_val_to_iso8601 g_time_zone_adjust_time g_time_zone_find_interval g_time_zone_get_abbreviation g_time_zone_get_offset g_time_zone_is_dst g_time_zone_new g_time_zone_new_local g_time_zone_new_utc g_time_zone_ref g_time_zone_unref g_timeout_add g_timeout_add_full g_timeout_add_seconds g_timeout_add_seconds_full g_timeout_source_new g_timeout_source_new_seconds g_timer_continue g_timer_destroy g_timer_elapsed g_timer_new g_timer_reset g_timer_start g_timer_stop g_trash_stack_height g_trash_stack_peek g_trash_stack_pop g_trash_stack_push g_tree_destroy g_tree_foreach g_tree_height g_tree_insert g_tree_lookup g_tree_lookup_extended g_tree_new g_tree_new_full g_tree_new_with_data g_tree_nnodes g_tree_ref g_tree_remove g_tree_replace g_tree_search g_tree_steal g_tree_unref g_try_malloc g_try_malloc0 g_try_malloc0_n g_try_malloc_n g_try_realloc g_try_realloc_n g_ucs4_to_utf16 g_ucs4_to_utf8 g_unichar_break_type g_unichar_combining_class g_unichar_digit_value g_unichar_get_mirror_char g_unichar_get_script g_unichar_isalnum g_unichar_isalpha g_unichar_iscntrl g_unichar_isdefined g_unichar_isdigit g_unichar_isgraph g_unichar_islower g_unichar_ismark g_unichar_isprint g_unichar_ispunct g_unichar_isspace g_unichar_istitle g_unichar_isupper g_unichar_iswide g_unichar_iswide_cjk g_unichar_isxdigit g_unichar_iszerowidth g_unichar_to_utf8 g_unichar_tolower g_unichar_totitle g_unichar_toupper g_unichar_type g_unichar_validate g_unichar_xdigit_value g_unicode_canonical_decomposition g_unicode_canonical_ordering g_unlink g_unsetenv g_uri_escape_string g_uri_list_extract_uris g_uri_parse_scheme g_uri_unescape_segment g_uri_unescape_string g_usleep g_utf16_to_ucs4 g_utf16_to_utf8 g_utf8_casefold g_utf8_collate g_utf8_collate_key g_utf8_collate_key_for_filename g_utf8_find_next_char g_utf8_find_prev_char g_utf8_get_char g_utf8_get_char_validated g_utf8_normalize g_utf8_offset_to_pointer g_utf8_pointer_to_offset g_utf8_prev_char g_utf8_strchr g_utf8_strdown g_utf8_strlen g_utf8_strncpy g_utf8_strrchr g_utf8_strreverse g_utf8_strup g_utf8_to_ucs4 g_utf8_to_ucs4_fast g_utf8_to_utf16 g_utf8_validate g_utime g_variant_builder_add g_variant_builder_add_parsed g_variant_builder_add_value g_variant_builder_clear g_variant_builder_close g_variant_builder_end g_variant_builder_init g_variant_builder_new g_variant_builder_open g_variant_builder_ref g_variant_builder_unref g_variant_byteswap g_variant_classify g_variant_compare g_variant_dup_bytestring g_variant_dup_bytestring_array g_variant_dup_string g_variant_dup_strv g_variant_equal g_variant_get g_variant_get_boolean g_variant_get_byte g_variant_get_bytestring g_variant_get_bytestring_array g_variant_get_child g_variant_get_child_value g_variant_get_data g_variant_get_double g_variant_get_fixed_array g_variant_get_handle g_variant_get_int16 g_variant_get_int32 g_variant_get_int64 g_variant_get_maybe g_variant_get_normal_form g_variant_get_size g_variant_get_string g_variant_get_strv g_variant_get_type g_variant_get_type_string g_variant_get_uint16 g_variant_get_uint32 g_variant_get_uint64 g_variant_get_va g_variant_get_variant g_variant_hash g_variant_is_container g_variant_is_floating g_variant_is_normal_form g_variant_is_object_path g_variant_is_of_type g_variant_is_signature g_variant_iter_copy g_variant_iter_free g_variant_iter_init g_variant_iter_loop g_variant_iter_n_children g_variant_iter_new g_variant_iter_next g_variant_iter_next_value g_variant_lookup g_variant_lookup_value g_variant_n_children g_variant_new g_variant_new_array g_variant_new_boolean g_variant_new_byte g_variant_new_bytestring g_variant_new_bytestring_array g_variant_new_dict_entry g_variant_new_double g_variant_new_from_data g_variant_new_handle g_variant_new_int16 g_variant_new_int32 g_variant_new_int64 g_variant_new_maybe g_variant_new_object_path g_variant_new_parsed g_variant_new_parsed_va g_variant_new_signature g_variant_new_string g_variant_new_strv g_variant_new_tuple g_variant_new_uint16 g_variant_new_uint32 g_variant_new_uint64 g_variant_new_va g_variant_new_variant g_variant_parse g_variant_parser_get_error_quark g_variant_print g_variant_print_string g_variant_ref g_variant_ref_sink g_variant_store g_variant_type_checked_ g_variant_type_copy g_variant_type_dup_string g_variant_type_element g_variant_type_equal g_variant_type_first g_variant_type_free g_variant_type_get_string_length g_variant_type_hash g_variant_type_is_array g_variant_type_is_basic g_variant_type_is_container g_variant_type_is_definite g_variant_type_is_dict_entry g_variant_type_is_maybe g_variant_type_is_subtype_of g_variant_type_is_tuple g_variant_type_is_variant g_variant_type_key g_variant_type_n_items g_variant_type_new g_variant_type_new_array g_variant_type_new_dict_entry g_variant_type_new_maybe g_variant_type_new_tuple g_variant_type_next g_variant_type_peek_string g_variant_type_string_is_valid g_variant_type_string_scan g_variant_type_value g_variant_unref g_vasprintf g_vfprintf g_vprintf g_vsnprintf g_vsprintf g_warn_message g_win32_error_message g_win32_ftruncate g_win32_get_package_installation_directory_of_module g_win32_get_system_data_dirs_for_module g_win32_get_windows_version g_win32_getlocale g_win32_locale_filename_from_utf8
syn keyword glibTypedef GDateDay GDateYear GIConv GPid GQuark GSequenceIter GStatBuf GTestCase GTestSuite GTime GTimeSpan gboolean gchar gconstpointer gdouble gfloat gint gint16 gint32 gint64 gint8 gintptr glong goffset gpointer gshort gsize gssize guchar guint guint16 guint32 guint64 guint8 guintptr gulong gunichar gunichar2 gushort
syn keyword glibConstant G_ASCII_ALNUM G_ASCII_ALPHA G_ASCII_CNTRL G_ASCII_DIGIT G_ASCII_GRAPH G_ASCII_LOWER G_ASCII_PRINT G_ASCII_PUNCT G_ASCII_SPACE G_ASCII_UPPER G_ASCII_XDIGIT G_BOOKMARK_FILE_ERROR_APP_NOT_REGISTERED G_BOOKMARK_FILE_ERROR_FILE_NOT_FOUND G_BOOKMARK_FILE_ERROR_INVALID_URI G_BOOKMARK_FILE_ERROR_INVALID_VALUE G_BOOKMARK_FILE_ERROR_READ G_BOOKMARK_FILE_ERROR_UNKNOWN_ENCODING G_BOOKMARK_FILE_ERROR_URI_NOT_FOUND G_BOOKMARK_FILE_ERROR_WRITE G_CHECKSUM_MD5 G_CHECKSUM_SHA1 G_CHECKSUM_SHA256 G_CONVERT_ERROR_BAD_URI G_CONVERT_ERROR_FAILED G_CONVERT_ERROR_ILLEGAL_SEQUENCE G_CONVERT_ERROR_NOT_ABSOLUTE_PATH G_CONVERT_ERROR_NO_CONVERSION G_CONVERT_ERROR_PARTIAL_INPUT G_DATE_APRIL G_DATE_AUGUST G_DATE_BAD_MONTH G_DATE_BAD_WEEKDAY G_DATE_DAY G_DATE_DECEMBER G_DATE_FEBRUARY G_DATE_FRIDAY G_DATE_JANUARY G_DATE_JULY G_DATE_JUNE G_DATE_MARCH G_DATE_MAY G_DATE_MONDAY G_DATE_MONTH G_DATE_NOVEMBER G_DATE_OCTOBER G_DATE_SATURDAY G_DATE_SEPTEMBER G_DATE_SUNDAY G_DATE_THURSDAY G_DATE_TUESDAY G_DATE_WEDNESDAY G_DATE_YEAR G_ERR_DIGIT_RADIX G_ERR_FLOAT_MALFORMED G_ERR_FLOAT_RADIX G_ERR_NON_DIGIT_IN_CONST G_ERR_UNEXP_EOF G_ERR_UNEXP_EOF_IN_COMMENT G_ERR_UNEXP_EOF_IN_STRING G_ERR_UNKNOWN G_FILE_ERROR_ACCES G_FILE_ERROR_AGAIN G_FILE_ERROR_BADF G_FILE_ERROR_EXIST G_FILE_ERROR_FAILED G_FILE_ERROR_FAULT G_FILE_ERROR_INTR G_FILE_ERROR_INVAL G_FILE_ERROR_IO G_FILE_ERROR_ISDIR G_FILE_ERROR_LOOP G_FILE_ERROR_MFILE G_FILE_ERROR_NAMETOOLONG G_FILE_ERROR_NFILE G_FILE_ERROR_NODEV G_FILE_ERROR_NOENT G_FILE_ERROR_NOMEM G_FILE_ERROR_NOSPC G_FILE_ERROR_NOSYS G_FILE_ERROR_NOTDIR G_FILE_ERROR_NXIO G_FILE_ERROR_PERM G_FILE_ERROR_PIPE G_FILE_ERROR_ROFS G_FILE_ERROR_TXTBSY G_FILE_TEST_EXISTS G_FILE_TEST_IS_DIR G_FILE_TEST_IS_EXECUTABLE G_FILE_TEST_IS_REGULAR G_FILE_TEST_IS_SYMLINK G_HOOK_FLAG_ACTIVE G_HOOK_FLAG_IN_CALL G_HOOK_FLAG_MASK G_IN_ORDER G_IO_CHANNEL_ERROR_FAILED G_IO_CHANNEL_ERROR_FBIG G_IO_CHANNEL_ERROR_INVAL G_IO_CHANNEL_ERROR_IO G_IO_CHANNEL_ERROR_ISDIR G_IO_CHANNEL_ERROR_NOSPC G_IO_CHANNEL_ERROR_NXIO G_IO_CHANNEL_ERROR_OVERFLOW G_IO_CHANNEL_ERROR_PIPE G_IO_ERR G_IO_ERROR_AGAIN G_IO_ERROR_INVAL G_IO_ERROR_NONE G_IO_ERROR_UNKNOWN G_IO_FLAG_APPEND G_IO_FLAG_GET_MASK G_IO_FLAG_IS_READABLE G_IO_FLAG_IS_SEEKABLE G_IO_FLAG_IS_WRITEABLE G_IO_FLAG_MASK G_IO_FLAG_NONBLOCK G_IO_FLAG_SET_MASK G_IO_HUP G_IO_IN G_IO_NVAL G_IO_OUT G_IO_PRI G_IO_STATUS_AGAIN G_IO_STATUS_EOF G_IO_STATUS_ERROR G_IO_STATUS_NORMAL G_KEY_FILE_ERROR_GROUP_NOT_FOUND G_KEY_FILE_ERROR_INVALID_VALUE G_KEY_FILE_ERROR_KEY_NOT_FOUND G_KEY_FILE_ERROR_NOT_FOUND G_KEY_FILE_ERROR_PARSE G_KEY_FILE_ERROR_UNKNOWN_ENCODING G_KEY_FILE_KEEP_COMMENTS G_KEY_FILE_KEEP_TRANSLATIONS G_KEY_FILE_NONE G_LEVEL_ORDER G_LOG_FLAG_FATAL G_LOG_FLAG_RECURSION G_LOG_LEVEL_CRITICAL G_LOG_LEVEL_DEBUG G_LOG_LEVEL_ERROR G_LOG_LEVEL_INFO G_LOG_LEVEL_MASK G_LOG_LEVEL_MESSAGE G_LOG_LEVEL_WARNING G_MARKUP_COLLECT_BOOLEAN G_MARKUP_COLLECT_INVALID G_MARKUP_COLLECT_OPTIONAL G_MARKUP_COLLECT_STRDUP G_MARKUP_COLLECT_STRING G_MARKUP_COLLECT_TRISTATE G_MARKUP_DO_NOT_USE_THIS_UNSUPPORTED_FLAG G_MARKUP_ERROR_BAD_UTF8 G_MARKUP_ERROR_EMPTY G_MARKUP_ERROR_INVALID_CONTENT G_MARKUP_ERROR_MISSING_ATTRIBUTE G_MARKUP_ERROR_PARSE G_MARKUP_ERROR_UNKNOWN_ATTRIBUTE G_MARKUP_ERROR_UNKNOWN_ELEMENT G_MARKUP_PREFIX_ERROR_POSITION G_MARKUP_TREAT_CDATA_AS_TEXT G_MODULE_BIND_LAZY G_MODULE_BIND_LOCAL G_MODULE_BIND_MASK G_NORMALIZE_ALL G_NORMALIZE_ALL_COMPOSE G_NORMALIZE_DEFAULT G_NORMALIZE_DEFAULT_COMPOSE G_NORMALIZE_NFC G_NORMALIZE_NFD G_NORMALIZE_NFKC G_NORMALIZE_NFKD G_ONCE_STATUS_NOTCALLED G_ONCE_STATUS_PROGRESS G_ONCE_STATUS_READY G_OPTION_ARG_CALLBACK G_OPTION_ARG_DOUBLE G_OPTION_ARG_FILENAME G_OPTION_ARG_FILENAME_ARRAY G_OPTION_ARG_INT G_OPTION_ARG_INT64 G_OPTION_ARG_NONE G_OPTION_ARG_STRING G_OPTION_ARG_STRING_ARRAY G_OPTION_ERROR_BAD_VALUE G_OPTION_ERROR_FAILED G_OPTION_ERROR_UNKNOWN_OPTION G_OPTION_FLAG_FILENAME G_OPTION_FLAG_HIDDEN G_OPTION_FLAG_IN_MAIN G_OPTION_FLAG_NOALIAS G_OPTION_FLAG_NO_ARG G_OPTION_FLAG_OPTIONAL_ARG G_OPTION_FLAG_REVERSE G_POST_ORDER G_PRE_ORDER G_REGEX_ANCHORED G_REGEX_CASELESS G_REGEX_DOLLAR_ENDONLY G_REGEX_DOTALL G_REGEX_DUPNAMES G_REGEX_ERROR_ASSERTION_EXPECTED G_REGEX_ERROR_COMPILE G_REGEX_ERROR_DEFINE_REPETION G_REGEX_ERROR_DUPLICATE_SUBPATTERN_NAME G_REGEX_ERROR_EXPRESSION_TOO_LARGE G_REGEX_ERROR_HEX_CODE_TOO_LARGE G_REGEX_ERROR_INCONSISTENT_NEWLINE_OPTIONS G_REGEX_ERROR_INEXISTENT_SUBPATTERN_REFERENCE G_REGEX_ERROR_INFINITE_LOOP G_REGEX_ERROR_INTERNAL G_REGEX_ERROR_INVALID_CONDITION G_REGEX_ERROR_INVALID_ESCAPE_IN_CHARACTER_CLASS G_REGEX_ERROR_INVALID_OCTAL_VALUE G_REGEX_ERROR_MALFORMED_CONDITION G_REGEX_ERROR_MALFORMED_PROPERTY G_REGEX_ERROR_MATCH G_REGEX_ERROR_MEMORY_ERROR G_REGEX_ERROR_MISSING_BACK_REFERENCE G_REGEX_ERROR_MISSING_CONTROL_CHAR G_REGEX_ERROR_MISSING_SUBPATTERN_NAME_TERMINATOR G_REGEX_ERROR_NOTHING_TO_REPEAT G_REGEX_ERROR_OPTIMIZE G_REGEX_ERROR_POSIX_COLLATING_ELEMENTS_NOT_SUPPORTED G_REGEX_ERROR_POSIX_NAMED_CLASS_OUTSIDE_CLASS G_REGEX_ERROR_QUANTIFIERS_OUT_OF_ORDER G_REGEX_ERROR_QUANTIFIER_TOO_BIG G_REGEX_ERROR_RANGE_OUT_OF_ORDER G_REGEX_ERROR_REPLACE G_REGEX_ERROR_SINGLE_BYTE_MATCH_IN_LOOKBEHIND G_REGEX_ERROR_STRAY_BACKSLASH G_REGEX_ERROR_SUBPATTERN_NAME_TOO_LONG G_REGEX_ERROR_TOO_MANY_BRANCHES_IN_DEFINE G_REGEX_ERROR_TOO_MANY_CONDITIONAL_BRANCHES G_REGEX_ERROR_TOO_MANY_SUBPATTERNS G_REGEX_ERROR_UNKNOWN_POSIX_CLASS_NAME G_REGEX_ERROR_UNKNOWN_PROPERTY G_REGEX_ERROR_UNMATCHED_PARENTHESIS G_REGEX_ERROR_UNRECOGNIZED_CHARACTER G_REGEX_ERROR_UNRECOGNIZED_ESCAPE G_REGEX_ERROR_UNTERMINATED_CHARACTER_CLASS G_REGEX_ERROR_UNTERMINATED_COMMENT G_REGEX_ERROR_VARIABLE_LENGTH_LOOKBEHIND G_REGEX_EXTENDED G_REGEX_MATCH_ANCHORED G_REGEX_MATCH_NEWLINE_ANY G_REGEX_MATCH_NEWLINE_CR G_REGEX_MATCH_NEWLINE_CRLF G_REGEX_MATCH_NEWLINE_LF G_REGEX_MATCH_NOTBOL G_REGEX_MATCH_NOTEMPTY G_REGEX_MATCH_NOTEOL G_REGEX_MATCH_PARTIAL G_REGEX_MULTILINE G_REGEX_NEWLINE_CR G_REGEX_NEWLINE_CRLF G_REGEX_NEWLINE_LF G_REGEX_NO_AUTO_CAPTURE G_REGEX_OPTIMIZE G_REGEX_RAW G_REGEX_UNGREEDY G_SEEK_CUR G_SEEK_END G_SEEK_SET G_SHELL_ERROR_BAD_QUOTING G_SHELL_ERROR_EMPTY_STRING G_SHELL_ERROR_FAILED G_SLICE_CONFIG_ALWAYS_MALLOC G_SLICE_CONFIG_BYPASS_MAGAZINES G_SLICE_CONFIG_CHUNK_SIZES G_SLICE_CONFIG_COLOR_INCREMENT G_SLICE_CONFIG_CONTENTION_COUNTER G_SLICE_CONFIG_WORKING_SET_MSECS G_SPAWN_CHILD_INHERITS_STDIN G_SPAWN_DO_NOT_REAP_CHILD G_SPAWN_ERROR_2BIG G_SPAWN_ERROR_ACCES G_SPAWN_ERROR_CHDIR G_SPAWN_ERROR_FAILED G_SPAWN_ERROR_FORK G_SPAWN_ERROR_INVAL G_SPAWN_ERROR_IO G_SPAWN_ERROR_ISDIR G_SPAWN_ERROR_LIBBAD G_SPAWN_ERROR_LOOP G_SPAWN_ERROR_MFILE G_SPAWN_ERROR_NAMETOOLONG G_SPAWN_ERROR_NFILE G_SPAWN_ERROR_NOENT G_SPAWN_ERROR_NOEXEC G_SPAWN_ERROR_NOMEM G_SPAWN_ERROR_NOTDIR G_SPAWN_ERROR_PERM G_SPAWN_ERROR_READ G_SPAWN_ERROR_TXTBUSY G_SPAWN_FILE_AND_ARGV_ZERO G_SPAWN_LEAVE_DESCRIPTORS_OPEN G_SPAWN_SEARCH_PATH G_SPAWN_STDERR_TO_DEV_NULL G_SPAWN_STDOUT_TO_DEV_NULL G_TEST_LOG_ERROR G_TEST_LOG_LIST_CASE G_TEST_LOG_MAX_RESULT G_TEST_LOG_MESSAGE G_TEST_LOG_MIN_RESULT G_TEST_LOG_NONE G_TEST_LOG_SKIP_CASE G_TEST_LOG_START_BINARY G_TEST_LOG_START_CASE G_TEST_LOG_STOP_CASE G_TEST_TRAP_INHERIT_STDIN G_TEST_TRAP_SILENCE_STDERR G_TEST_TRAP_SILENCE_STDOUT G_THREAD_ERROR_AGAIN G_THREAD_PRIORITY_HIGH G_THREAD_PRIORITY_LOW G_THREAD_PRIORITY_NORMAL G_THREAD_PRIORITY_URGENT G_TIME_TYPE_DAYLIGHT G_TIME_TYPE_STANDARD G_TIME_TYPE_UNIVERSAL G_TOKEN_BINARY G_TOKEN_CHAR G_TOKEN_COMMA G_TOKEN_COMMENT_MULTI G_TOKEN_COMMENT_SINGLE G_TOKEN_EOF G_TOKEN_EQUAL_SIGN G_TOKEN_ERROR G_TOKEN_FLOAT G_TOKEN_HEX G_TOKEN_IDENTIFIER G_TOKEN_IDENTIFIER_NULL G_TOKEN_INT G_TOKEN_LAST G_TOKEN_LEFT_BRACE G_TOKEN_LEFT_CURLY G_TOKEN_LEFT_PAREN G_TOKEN_NONE G_TOKEN_OCTAL G_TOKEN_RIGHT_BRACE G_TOKEN_RIGHT_CURLY G_TOKEN_RIGHT_PAREN G_TOKEN_STRING G_TOKEN_SYMBOL G_TRAVERSE_ALL G_TRAVERSE_LEAFS G_TRAVERSE_LEAVES G_TRAVERSE_MASK G_TRAVERSE_NON_LEAFS G_TRAVERSE_NON_LEAVES G_UNICODE_BREAK_AFTER G_UNICODE_BREAK_ALPHABETIC G_UNICODE_BREAK_AMBIGUOUS G_UNICODE_BREAK_BEFORE G_UNICODE_BREAK_BEFORE_AND_AFTER G_UNICODE_BREAK_CARRIAGE_RETURN G_UNICODE_BREAK_CLOSE_PARANTHESIS G_UNICODE_BREAK_CLOSE_PUNCTUATION G_UNICODE_BREAK_COMBINING_MARK G_UNICODE_BREAK_COMPLEX_CONTEXT G_UNICODE_BREAK_CONTINGENT G_UNICODE_BREAK_EXCLAMATION G_UNICODE_BREAK_HANGUL_LVT_SYLLABLE G_UNICODE_BREAK_HANGUL_LV_SYLLABLE G_UNICODE_BREAK_HANGUL_L_JAMO G_UNICODE_BREAK_HANGUL_T_JAMO G_UNICODE_BREAK_HANGUL_V_JAMO G_UNICODE_BREAK_HYPHEN G_UNICODE_BREAK_IDEOGRAPHIC G_UNICODE_BREAK_INFIX_SEPARATOR G_UNICODE_BREAK_INSEPARABLE G_UNICODE_BREAK_LINE_FEED G_UNICODE_BREAK_MANDATORY G_UNICODE_BREAK_NEXT_LINE G_UNICODE_BREAK_NON_BREAKING_GLUE G_UNICODE_BREAK_NON_STARTER G_UNICODE_BREAK_NUMERIC G_UNICODE_BREAK_OPEN_PUNCTUATION G_UNICODE_BREAK_POSTFIX G_UNICODE_BREAK_PREFIX G_UNICODE_BREAK_QUOTATION G_UNICODE_BREAK_SPACE G_UNICODE_BREAK_SURROGATE G_UNICODE_BREAK_SYMBOL G_UNICODE_BREAK_UNKNOWN G_UNICODE_BREAK_WORD_JOINER G_UNICODE_BREAK_ZERO_WIDTH_SPACE G_UNICODE_CLOSE_PUNCTUATION G_UNICODE_COMBINING_MARK G_UNICODE_CONNECT_PUNCTUATION G_UNICODE_CONTROL G_UNICODE_CURRENCY_SYMBOL G_UNICODE_DASH_PUNCTUATION G_UNICODE_DECIMAL_NUMBER G_UNICODE_ENCLOSING_MARK G_UNICODE_FINAL_PUNCTUATION G_UNICODE_FORMAT G_UNICODE_INITIAL_PUNCTUATION G_UNICODE_LETTER_NUMBER G_UNICODE_LINE_SEPARATOR G_UNICODE_LOWERCASE_LETTER G_UNICODE_MATH_SYMBOL G_UNICODE_MODIFIER_LETTER G_UNICODE_MODIFIER_SYMBOL G_UNICODE_NON_SPACING_MARK G_UNICODE_OPEN_PUNCTUATION G_UNICODE_OTHER_LETTER G_UNICODE_OTHER_NUMBER G_UNICODE_OTHER_PUNCTUATION G_UNICODE_OTHER_SYMBOL G_UNICODE_PARAGRAPH_SEPARATOR G_UNICODE_PRIVATE_USE G_UNICODE_SCRIPT_ARABIC G_UNICODE_SCRIPT_ARMENIAN G_UNICODE_SCRIPT_AVESTAN G_UNICODE_SCRIPT_BALINESE G_UNICODE_SCRIPT_BAMUM G_UNICODE_SCRIPT_BATAK G_UNICODE_SCRIPT_BENGALI G_UNICODE_SCRIPT_BOPOMOFO G_UNICODE_SCRIPT_BRAHMI G_UNICODE_SCRIPT_BRAILLE G_UNICODE_SCRIPT_BUGINESE G_UNICODE_SCRIPT_BUHID G_UNICODE_SCRIPT_CANADIAN_ABORIGINAL G_UNICODE_SCRIPT_CARIAN G_UNICODE_SCRIPT_CHAM G_UNICODE_SCRIPT_CHEROKEE G_UNICODE_SCRIPT_COMMON G_UNICODE_SCRIPT_COPTIC G_UNICODE_SCRIPT_CUNEIFORM G_UNICODE_SCRIPT_CYPRIOT G_UNICODE_SCRIPT_CYRILLIC G_UNICODE_SCRIPT_DESERET G_UNICODE_SCRIPT_DEVANAGARI G_UNICODE_SCRIPT_EGYPTIAN_HIEROGLYPHS G_UNICODE_SCRIPT_ETHIOPIC G_UNICODE_SCRIPT_GEORGIAN G_UNICODE_SCRIPT_GLAGOLITIC G_UNICODE_SCRIPT_GOTHIC G_UNICODE_SCRIPT_GREEK G_UNICODE_SCRIPT_GUJARATI G_UNICODE_SCRIPT_GURMUKHI G_UNICODE_SCRIPT_HAN G_UNICODE_SCRIPT_HANGUL G_UNICODE_SCRIPT_HANUNOO G_UNICODE_SCRIPT_HEBREW G_UNICODE_SCRIPT_HIRAGANA G_UNICODE_SCRIPT_IMPERIAL_ARAMAIC G_UNICODE_SCRIPT_INHERITED G_UNICODE_SCRIPT_INSCRIPTIONAL_PAHLAVI G_UNICODE_SCRIPT_INSCRIPTIONAL_PARTHIAN G_UNICODE_SCRIPT_INVALID_CODE G_UNICODE_SCRIPT_JAVANESE G_UNICODE_SCRIPT_KAITHI G_UNICODE_SCRIPT_KANNADA G_UNICODE_SCRIPT_KATAKANA G_UNICODE_SCRIPT_KAYAH_LI G_UNICODE_SCRIPT_KHAROSHTHI G_UNICODE_SCRIPT_KHMER G_UNICODE_SCRIPT_LAO G_UNICODE_SCRIPT_LATIN G_UNICODE_SCRIPT_LEPCHA G_UNICODE_SCRIPT_LIMBU G_UNICODE_SCRIPT_LINEAR_B G_UNICODE_SCRIPT_LISU G_UNICODE_SCRIPT_LYCIAN G_UNICODE_SCRIPT_LYDIAN G_UNICODE_SCRIPT_MALAYALAM G_UNICODE_SCRIPT_MANDAIC G_UNICODE_SCRIPT_MEETEI_MAYEK G_UNICODE_SCRIPT_MONGOLIAN G_UNICODE_SCRIPT_MYANMAR G_UNICODE_SCRIPT_NEW_TAI_LUE G_UNICODE_SCRIPT_NKO G_UNICODE_SCRIPT_OGHAM G_UNICODE_SCRIPT_OLD_ITALIC G_UNICODE_SCRIPT_OLD_PERSIAN G_UNICODE_SCRIPT_OLD_SOUTH_ARABIAN G_UNICODE_SCRIPT_OLD_TURKIC G_UNICODE_SCRIPT_OL_CHIKI G_UNICODE_SCRIPT_ORIYA G_UNICODE_SCRIPT_OSMANYA G_UNICODE_SCRIPT_PHAGS_PA G_UNICODE_SCRIPT_PHOENICIAN G_UNICODE_SCRIPT_REJANG G_UNICODE_SCRIPT_RUNIC G_UNICODE_SCRIPT_SAMARITAN G_UNICODE_SCRIPT_SAURASHTRA G_UNICODE_SCRIPT_SHAVIAN G_UNICODE_SCRIPT_SINHALA G_UNICODE_SCRIPT_SUNDANESE G_UNICODE_SCRIPT_SYLOTI_NAGRI G_UNICODE_SCRIPT_SYRIAC G_UNICODE_SCRIPT_TAGALOG G_UNICODE_SCRIPT_TAGBANWA G_UNICODE_SCRIPT_TAI_LE G_UNICODE_SCRIPT_TAI_THAM G_UNICODE_SCRIPT_TAI_VIET G_UNICODE_SCRIPT_TAMIL G_UNICODE_SCRIPT_TELUGU G_UNICODE_SCRIPT_THAANA G_UNICODE_SCRIPT_THAI G_UNICODE_SCRIPT_TIBETAN G_UNICODE_SCRIPT_TIFINAGH G_UNICODE_SCRIPT_UGARITIC G_UNICODE_SCRIPT_UNKNOWN G_UNICODE_SCRIPT_VAI G_UNICODE_SCRIPT_YI G_UNICODE_SPACE_SEPARATOR G_UNICODE_SURROGATE G_UNICODE_TITLECASE_LETTER G_UNICODE_UNASSIGNED G_UNICODE_UPPERCASE_LETTER G_USER_DIRECTORY_DESKTOP G_USER_DIRECTORY_DOCUMENTS G_USER_DIRECTORY_DOWNLOAD G_USER_DIRECTORY_MUSIC G_USER_DIRECTORY_PICTURES G_USER_DIRECTORY_PUBLIC_SHARE G_USER_DIRECTORY_TEMPLATES G_USER_DIRECTORY_VIDEOS G_USER_N_DIRECTORIES G_VARIANT_CLASS_ARRAY G_VARIANT_CLASS_BOOLEAN G_VARIANT_CLASS_BYTE G_VARIANT_CLASS_DICT_ENTRY G_VARIANT_CLASS_DOUBLE G_VARIANT_CLASS_HANDLE G_VARIANT_CLASS_INT16 G_VARIANT_CLASS_INT32 G_VARIANT_CLASS_INT64 G_VARIANT_CLASS_MAYBE G_VARIANT_CLASS_OBJECT_PATH G_VARIANT_CLASS_SIGNATURE G_VARIANT_CLASS_STRING G_VARIANT_CLASS_TUPLE G_VARIANT_CLASS_UINT16 G_VARIANT_CLASS_UINT32 G_VARIANT_CLASS_UINT64 G_VARIANT_CLASS_VARIANT G_VARIANT_PARSE_ERROR_BASIC_TYPE_EXPECTED G_VARIANT_PARSE_ERROR_CANNOT_INFER_TYPE G_VARIANT_PARSE_ERROR_DEFINITE_TYPE_EXPECTED G_VARIANT_PARSE_ERROR_FAILED G_VARIANT_PARSE_ERROR_INPUT_NOT_AT_END G_VARIANT_PARSE_ERROR_INVALID_CHARACTER G_VARIANT_PARSE_ERROR_INVALID_FORMAT_STRING G_VARIANT_PARSE_ERROR_INVALID_OBJECT_PATH G_VARIANT_PARSE_ERROR_INVALID_SIGNATURE G_VARIANT_PARSE_ERROR_INVALID_TYPE_STRING G_VARIANT_PARSE_ERROR_NO_COMMON_TYPE G_VARIANT_PARSE_ERROR_NUMBER_OUT_OF_RANGE G_VARIANT_PARSE_ERROR_NUMBER_TOO_BIG G_VARIANT_PARSE_ERROR_TYPE_ERROR G_VARIANT_PARSE_ERROR_UNEXPECTED_TOKEN G_VARIANT_PARSE_ERROR_UNKNOWN_KEYWORD G_VARIANT_PARSE_ERROR_UNTERMINATED_STRING_CONSTANT G_VARIANT_PARSE_ERROR_VALUE_EXPECTED
syn keyword glibStruct GArray GAsyncQueue GBookmarkFile GByteArray GCache GChecksum GCompletion GCond GData GDate GDateTime GDebugKey GDir GError GHashTable GHashTableIter GHook GHookList GIOChannel GIOFuncs GKeyFile GList GMainContext GMainLoop GMappedFile GMarkupParseContext GMarkupParser GMatchInfo GMemVTable GModule GMutex GNode GOnce GOptionContext GOptionEntry GOptionGroup GPatternSpec GPollFD GPrivate GPtrArray GQueue GRand GRegex GRelation GSList GScanner GScannerConfig GSequence GSource GSourceCallbackFuncs GSourceFuncs GSourcePrivate GStaticMutex GStaticPrivate GStaticRWLock GStaticRecMutex GString GStringChunk GTestConfig GTestLogBuffer GTestLogMsg GThread GThreadFunctions GThreadPool GTimeVal GTimeZone GTimer GTrashStack GTree GTuples GVariant GVariantBuilder GVariantIter GVariantType utimbuf
syn keyword glibUnion GDoubleIEEE754 GFloatIEEE754 GSystemThread GTokenValue
syn keyword glibMacro ABS ATEXIT CLAMP C_ GINT16_FROM_BE GINT16_FROM_LE GINT16_TO_BE GINT16_TO_LE GINT32_FROM_BE GINT32_FROM_LE GINT32_TO_BE GINT32_TO_LE GINT64_FROM_BE GINT64_FROM_LE GINT64_TO_BE GINT64_TO_LE GINT_FROM_BE GINT_FROM_LE GINT_TO_BE GINT_TO_LE GINT_TO_POINTER GLIB_CHECK_VERSION GLONG_FROM_BE GLONG_FROM_LE GLONG_TO_BE GLONG_TO_LE GPOINTER_TO_INT GPOINTER_TO_SIZE GPOINTER_TO_UINT GSIZE_FROM_BE GSIZE_FROM_LE GSIZE_TO_BE GSIZE_TO_LE GSIZE_TO_POINTER GSSIZE_FROM_BE GSSIZE_FROM_LE GSSIZE_TO_BE GSSIZE_TO_LE GUINT16_FROM_BE GUINT16_FROM_LE GUINT16_SWAP_BE_PDP GUINT16_SWAP_LE_BE GUINT16_SWAP_LE_BE_CONSTANT GUINT16_SWAP_LE_BE_IA32 GUINT16_SWAP_LE_BE_IA64 GUINT16_SWAP_LE_PDP GUINT16_TO_BE GUINT16_TO_LE GUINT32_FROM_BE GUINT32_FROM_LE GUINT32_SWAP_BE_PDP GUINT32_SWAP_LE_BE GUINT32_SWAP_LE_BE_CONSTANT GUINT32_SWAP_LE_BE_IA32 GUINT32_SWAP_LE_BE_IA64 GUINT32_SWAP_LE_BE_X86_64 GUINT32_SWAP_LE_PDP GUINT32_TO_BE GUINT32_TO_LE GUINT64_FROM_BE GUINT64_FROM_LE GUINT64_SWAP_LE_BE GUINT64_SWAP_LE_BE_CONSTANT GUINT64_SWAP_LE_BE_IA32 GUINT64_SWAP_LE_BE_IA64 GUINT64_SWAP_LE_BE_X86_64 GUINT64_TO_BE GUINT64_TO_LE GUINT_FROM_BE GUINT_FROM_LE GUINT_TO_BE GUINT_TO_LE GUINT_TO_POINTER GULONG_FROM_BE GULONG_FROM_LE GULONG_TO_BE GULONG_TO_LE G_BREAKPOINT G_GINT64_CONSTANT G_GNUC_ALLOC_SIZE G_GNUC_ALLOC_SIZE2 G_GNUC_DEPRECATED_FOR G_GNUC_FORMAT G_GNUC_PRINTF G_GNUC_SCANF G_GOFFSET_CONSTANT G_GUINT64_CONSTANT G_HOOK G_HOOK_ACTIVE G_HOOK_FLAGS G_HOOK_IN_CALL G_HOOK_IS_UNLINKED G_HOOK_IS_VALID G_IS_DIR_SEPARATOR G_LIKELY G_LOCK G_LOCK_DEFINE G_LOCK_DEFINE_STATIC G_LOCK_EXTERN G_LOCK_NAME G_NODE_IS_LEAF G_NODE_IS_ROOT G_N_ELEMENTS G_PASTE G_PASTE_ARGS G_STATIC_ASSERT G_STRINGIFY G_STRINGIFY_ARG G_STRUCT_MEMBER G_STRUCT_MEMBER_P G_STRUCT_OFFSET G_THREAD_CF G_THREAD_ECF G_THREAD_UF G_TRYLOCK G_UNLIKELY G_UNLOCK G_VARIANT_TYPE G_VA_COPY G_WIN32_HAVE_WIDECHAR_API G_WIN32_IS_NT_BASED MAX MIN NC_ N_ Q_ alloca g_ATEXIT g_alloca g_array_append_val g_array_index g_array_insert_val g_array_prepend_val g_ascii_isalnum g_ascii_isalpha g_ascii_iscntrl g_ascii_isdigit g_ascii_isgraph g_ascii_islower g_ascii_isprint g_ascii_ispunct g_ascii_isspace g_ascii_isupper g_ascii_isxdigit g_assert g_assert_cmpfloat g_assert_cmphex g_assert_cmpint g_assert_cmpstr g_assert_cmpuint g_assert_error g_assert_no_error g_assert_not_reached g_atexit g_atomic_int_dec_and_test g_atomic_int_get g_atomic_int_inc g_atomic_int_set g_atomic_pointer_get g_atomic_pointer_set g_cond_broadcast g_cond_free g_cond_new g_cond_signal g_cond_timed_wait g_cond_wait g_critical g_datalist_get_data g_datalist_id_remove_data g_datalist_id_set_data g_datalist_remove_data g_datalist_remove_no_notify g_datalist_set_data g_datalist_set_data_full g_dataset_get_data g_dataset_id_remove_data g_dataset_id_set_data g_dataset_remove_data g_dataset_remove_no_notify g_dataset_set_data g_dataset_set_data_full g_debug g_error g_hook_append g_htonl g_htons g_list_free1 g_list_next g_list_previous g_memmove g_message g_mutex_free g_mutex_lock g_mutex_new g_mutex_trylock g_mutex_unlock g_new g_new0 g_newa g_node_append g_node_append_data g_node_first_child g_node_insert_data g_node_insert_data_before g_node_next_sibling g_node_prepend_data g_node_prev_sibling g_ntohl g_ntohs g_once g_private_get g_private_new g_private_set g_ptr_array_index g_rand_boolean g_random_boolean g_renew g_return_if_fail g_return_if_reached g_return_val_if_fail g_return_val_if_reached g_slice_dup g_slice_free g_slice_free_chain g_slice_new g_slice_new0 g_slist_free1 g_slist_next g_static_mutex_get_mutex g_static_mutex_get_mutex_impl_shortcut g_static_mutex_lock g_static_mutex_trylock g_static_mutex_unlock g_string_append_c g_strstrip g_system_thread_assign g_system_thread_equal g_system_thread_equal_simple g_test_add g_test_perf g_test_queue_unref g_test_quick g_test_quiet g_test_rand_bit g_test_slow g_test_thorough g_test_trap_assert_failed g_test_trap_assert_passed g_test_trap_assert_stderr g_test_trap_assert_stderr_unmatched g_test_trap_assert_stdout g_test_trap_assert_stdout_unmatched g_test_verbose g_thread_create g_thread_init g_thread_supported g_thread_yield g_try_new g_try_new0 g_try_renew g_utf8_next_char g_warn_if_fail g_warn_if_reached g_warning
syn keyword glibEnum GAsciiType GBookmarkFileError GChecksumType GConvertError GDateDMY GDateMonth GDateWeekday GErrorType GFileError GFileTest GHookFlagMask GIOChannelError GIOCondition GIOError GIOFlags GIOStatus GKeyFileError GKeyFileFlags GLogLevelFlags GMarkupCollectType GMarkupError GMarkupParseFlags GModuleFlags GNormalizeMode GOnceStatus GOptionArg GOptionError GOptionFlags GRegexCompileFlags GRegexError GRegexMatchFlags GSeekType GShellError GSliceConfig GSpawnError GSpawnFlags GTestLogType GTestTrapFlags GThreadError GThreadPriority GTimeType GTokenType GTraverseFlags GTraverseType GUnicodeBreakType GUnicodeScript GUnicodeType GUserDirectory GVariantClass GVariantParseError
syn keyword glibVariable g_child_watch_funcs g_idle_funcs g_io_watch_funcs g_mem_gc_friendly g_thread_functions_for_glib_use g_thread_use_default_impl g_threads_got_initialized g_timeout_funcs glib_mem_profiler_table
syn keyword glibUserFunction GCacheDestroyFunc GCacheDupFunc GCacheNewFunc GChildWatchFunc GCompareDataFunc GCompareFunc GCompletionFunc GCompletionStrncmpFunc GCopyFunc GDataForeachFunc GDestroyNotify GEqualFunc GFreeFunc GFunc GHFunc GHRFunc GHashFunc GHookCheckFunc GHookCheckMarshaller GHookCompareFunc GHookFinalizeFunc GHookFindFunc GHookFunc GHookMarshaller GIOFunc GLogFunc GModuleCheckInit GModuleUnload GNodeForeachFunc GNodeTraverseFunc GOptionArgFunc GOptionErrorFunc GOptionParseFunc GPollFunc GPrintFunc GRegexEvalCallback GScannerMsgFunc GSequenceIterCompareFunc GSourceDummyMarshal GSourceFunc GSpawnChildSetupFunc GTestDataFunc GTestFixtureFunc GTestFunc GTestLogFatalFunc GThreadFunc GTranslateFunc GTraverseFunc GVoidFunc g_thread_gettime
syn keyword glibDefine FALSE GLIB_HAVE_ALLOCA_H GLIB_HAVE_SYS_POLL_H GLIB_MAJOR_VERSION GLIB_MICRO_VERSION GLIB_MINOR_VERSION GLIB_SIZEOF_LONG GLIB_SIZEOF_SIZE_T GLIB_SIZEOF_VOID_P GLIB_SYSDEF_AF_INET GLIB_SYSDEF_AF_INET6 GLIB_SYSDEF_AF_UNIX GLIB_SYSDEF_MSG_DONTROUTE GLIB_SYSDEF_MSG_OOB GLIB_SYSDEF_MSG_PEEK GLIB_SYSDEF_POLLERR GLIB_SYSDEF_POLLHUP GLIB_SYSDEF_POLLIN GLIB_SYSDEF_POLLNVAL GLIB_SYSDEF_POLLOUT GLIB_SYSDEF_POLLPRI GLIB_USING_SYSTEM_PRINTF GLIB_VAR G_ASCII_DTOSTR_BUF_SIZE G_ATOMIC_OP_MEMORY_BARRIER_NEEDED G_BEGIN_DECLS G_BIG_ENDIAN G_BOOKMARK_FILE_ERROR G_BYTE_ORDER G_CAN_INLINE G_CONST_RETURN G_CONVERT_ERROR G_CSET_A_2_Z G_CSET_DIGITS G_CSET_LATINC G_CSET_LATINS G_CSET_a_2_z G_DATALIST_FLAGS_MASK G_DATE_BAD_DAY G_DATE_BAD_JULIAN G_DATE_BAD_YEAR G_DIR_SEPARATOR G_DIR_SEPARATOR_S G_E G_END_DECLS G_FILE_ERROR G_GINT16_FORMAT G_GINT16_MODIFIER G_GINT32_FORMAT G_GINT32_MODIFIER G_GINT64_FORMAT G_GINT64_MODIFIER G_GINTPTR_FORMAT G_GINTPTR_MODIFIER G_GNUC_CONST G_GNUC_DEPRECATED G_GNUC_EXTENSION G_GNUC_INTERNAL G_GNUC_MALLOC G_GNUC_MAY_ALIAS G_GNUC_NORETURN G_GNUC_NO_INSTRUMENT G_GNUC_NULL_TERMINATED G_GNUC_PURE G_GNUC_UNUSED G_GNUC_WARN_UNUSED_RESULT G_GOFFSET_FORMAT G_GOFFSET_MODIFIER G_GSIZE_FORMAT G_GSIZE_MODIFIER G_GSSIZE_FORMAT G_GUINT16_FORMAT G_GUINT32_FORMAT G_GUINT64_FORMAT G_GUINTPTR_FORMAT G_HAVE_GINT64 G_HAVE_GNUC_VARARGS G_HAVE_GNUC_VISIBILITY G_HAVE_GROWING_STACK G_HAVE_INLINE G_HAVE_ISO_VARARGS G_HAVE___INLINE G_HAVE___INLINE__ G_HOOK_FLAG_USER_SHIFT G_IEEE754_DOUBLE_BIAS G_IEEE754_FLOAT_BIAS G_INLINE_FUNC G_IO_CHANNEL_ERROR G_KEY_FILE_DESKTOP_GROUP G_KEY_FILE_DESKTOP_KEY_CATEGORIES G_KEY_FILE_DESKTOP_KEY_COMMENT G_KEY_FILE_DESKTOP_KEY_EXEC G_KEY_FILE_DESKTOP_KEY_GENERIC_NAME G_KEY_FILE_DESKTOP_KEY_HIDDEN G_KEY_FILE_DESKTOP_KEY_ICON G_KEY_FILE_DESKTOP_KEY_MIME_TYPE G_KEY_FILE_DESKTOP_KEY_NAME G_KEY_FILE_DESKTOP_KEY_NOT_SHOW_IN G_KEY_FILE_DESKTOP_KEY_NO_DISPLAY G_KEY_FILE_DESKTOP_KEY_ONLY_SHOW_IN G_KEY_FILE_DESKTOP_KEY_PATH G_KEY_FILE_DESKTOP_KEY_STARTUP_NOTIFY G_KEY_FILE_DESKTOP_KEY_STARTUP_WM_CLASS G_KEY_FILE_DESKTOP_KEY_TERMINAL G_KEY_FILE_DESKTOP_KEY_TRY_EXEC G_KEY_FILE_DESKTOP_KEY_TYPE G_KEY_FILE_DESKTOP_KEY_URL G_KEY_FILE_DESKTOP_KEY_VERSION G_KEY_FILE_DESKTOP_TYPE_APPLICATION G_KEY_FILE_DESKTOP_TYPE_DIRECTORY G_KEY_FILE_DESKTOP_TYPE_LINK G_KEY_FILE_ERROR G_LITTLE_ENDIAN G_LN10 G_LN2 G_LOG_2_BASE_10 G_LOG_DOMAIN G_LOG_FATAL_MASK G_LOG_LEVEL_USER_SHIFT G_MARKUP_ERROR G_MAXDOUBLE G_MAXFLOAT G_MAXINT G_MAXINT16 G_MAXINT32 G_MAXINT64 G_MAXINT8 G_MAXLONG G_MAXOFFSET G_MAXSHORT G_MAXSIZE G_MAXSSIZE G_MAXUINT G_MAXUINT16 G_MAXUINT32 G_MAXUINT64 G_MAXUINT8 G_MAXULONG G_MAXUSHORT G_MEM_ALIGN G_MINDOUBLE G_MINFLOAT G_MININT G_MININT16 G_MININT32 G_MININT64 G_MININT8 G_MINLONG G_MINOFFSET G_MINSHORT G_MINSSIZE G_MODULE_EXPORT G_MODULE_IMPORT G_MODULE_SUFFIX G_MUTEX_DEBUG_MAGIC G_NATIVE_ATEXIT G_ONCE_INIT G_OPTION_ERROR G_OPTION_REMAINING G_OS_UNIX G_PDP_ENDIAN G_PI G_PI_2 G_PI_4 G_POLLFD_FORMAT G_PRIORITY_DEFAULT G_PRIORITY_DEFAULT_IDLE G_PRIORITY_HIGH G_PRIORITY_HIGH_IDLE G_PRIORITY_LOW G_QUEUE_INIT G_REGEX_ERROR G_SEARCHPATH_SEPARATOR G_SEARCHPATH_SEPARATOR_S G_SHELL_ERROR G_SPAWN_ERROR G_SQRT2 G_STATIC_MUTEX_INIT G_STATIC_PRIVATE_INIT G_STATIC_REC_MUTEX_INIT G_STATIC_RW_LOCK_INIT G_STMT_END G_STMT_START G_STRFUNC G_STRLOC G_STR_DELIMITERS G_THREADS_ENABLED G_THREADS_IMPL_POSIX G_THREAD_ERROR G_TIME_SPAN_DAY G_TIME_SPAN_HOUR G_TIME_SPAN_MILLISECOND G_TIME_SPAN_MINUTE G_TIME_SPAN_SECOND G_URI_RESERVED_CHARS_ALLOWED_IN_PATH G_URI_RESERVED_CHARS_ALLOWED_IN_PATH_ELEMENT G_URI_RESERVED_CHARS_ALLOWED_IN_USERINFO G_URI_RESERVED_CHARS_GENERIC_DELIMITERS G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS G_USEC_PER_SEC G_VARIANT_PARSE_ERROR G_VARIANT_TYPE_ANY G_VARIANT_TYPE_ARRAY G_VARIANT_TYPE_BASIC G_VARIANT_TYPE_BOOLEAN G_VARIANT_TYPE_BYTE G_VARIANT_TYPE_BYTESTRING G_VARIANT_TYPE_BYTESTRING_ARRAY G_VARIANT_TYPE_DICTIONARY G_VARIANT_TYPE_DICT_ENTRY G_VARIANT_TYPE_DOUBLE G_VARIANT_TYPE_HANDLE G_VARIANT_TYPE_INT16 G_VARIANT_TYPE_INT32 G_VARIANT_TYPE_INT64 G_VARIANT_TYPE_MAYBE G_VARIANT_TYPE_OBJECT_PATH G_VARIANT_TYPE_SIGNATURE G_VARIANT_TYPE_STRING G_VARIANT_TYPE_STRING_ARRAY G_VARIANT_TYPE_TUPLE G_VARIANT_TYPE_UINT16 G_VARIANT_TYPE_UINT32 G_VARIANT_TYPE_UINT64 G_VARIANT_TYPE_UNIT G_VARIANT_TYPE_VARIANT G_VA_COPY G_VA_COPY_AS_ARRAY G_WIN32_MSG_HANDLE MAXPATHLEN NULL TRUE inline
syn keyword glibDeprecatedFunction g_allocator_free g_allocator_new g_assert_warning g_async_queue_ref_unlocked g_async_queue_unref_and_unlock g_basename g_blow_chunks g_cache_value_foreach g_completion_add_items g_completion_clear_items g_completion_complete g_completion_complete_utf8 g_completion_free g_completion_new g_completion_remove_items g_completion_set_compare g_date_set_time g_io_channel_close g_io_channel_read g_io_channel_seek g_io_channel_write g_list_pop_allocator g_list_push_allocator g_mapped_file_free g_mem_chunk_alloc g_mem_chunk_alloc0 g_mem_chunk_clean g_mem_chunk_destroy g_mem_chunk_free g_mem_chunk_info g_mem_chunk_new g_mem_chunk_print g_mem_chunk_reset g_node_pop_allocator g_node_push_allocator g_relation_count g_relation_delete g_relation_destroy g_relation_exists g_relation_index g_relation_insert g_relation_new g_relation_print g_relation_select g_slist_pop_allocator g_slist_push_allocator g_source_get_current_time g_strcasecmp g_strdown g_string_down g_string_up g_strncasecmp g_strup g_tree_traverse g_tuples_destroy g_tuples_index g_win32_get_package_installation_directory g_win32_get_package_installation_subdirectory
syn keyword glibDeprecatedStruct GAllocator GMemChunk
syn keyword glibDeprecatedMacro G_WIN32_DLLMAIN_FOR_DLL_NAME g_chunk_free g_chunk_new g_chunk_new0 g_date_day g_date_day_of_year g_date_days_in_month g_date_julian g_date_monday_week_of_year g_date_monday_weeks_in_year g_date_month g_date_sunday_week_of_year g_date_sunday_weeks_in_year g_date_weekday g_date_year g_dirname g_hash_table_freeze g_hash_table_thaw g_main_destroy g_main_is_running g_main_iteration g_main_new g_main_pending g_main_quit g_main_run g_main_set_poll_func g_mem_chunk_create g_scanner_add_symbol g_scanner_foreach_symbol g_scanner_freeze_symbol_table g_scanner_remove_symbol g_scanner_thaw_symbol_table g_string_sprintf g_string_sprintfa
syn keyword glibDeprecatedDefine G_ALLOCATOR_LIST G_ALLOCATOR_NODE G_ALLOCATOR_SLIST G_ALLOC_AND_FREE G_ALLOC_ONLY G_GNUC_FUNCTION G_GNUC_PRETTY_FUNCTION

" Default highlighting
if version >= 508 || !exists("did_glib_syntax_inits")
  if version < 508
    let did_glib_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif
  HiLink glibFunction Function
  HiLink glibTypedef Type
  HiLink glibConstant Constant
  HiLink glibStruct Type
  HiLink glibUnion Type
  HiLink glibMacro Macro
  HiLink glibEnum Type
  HiLink glibVariable Identifier
  HiLink glibUserFunction Type
  HiLink glibDefine Constant
  if exists("glib_deprecated_errors")
    HiLink glibDeprecatedFunction Error
    HiLink glibDeprecatedMacro Error
    HiLink glibDeprecatedStruct Error
    HiLink glibDeprecatedDefine Error
  elseif exists("glib_enable_deprecated")
    HiLink glibDeprecatedFunction Function
    HiLink glibDeprecatedMacro Macro
    HiLink glibDeprecatedStruct Type
    HiLink glibDeprecatedDefine Constant
  endif

  delcommand HiLink
endif

